@@ -126,6 +126,11 @@ struct InfoBoxData {
    */
   void SetValueFromSpeed(fixed value, bool precision=true);
 
+  /**
+   * Set the InfoBox value to the specified task speed.
+   */
+  void SetValueFromTaskSpeed(fixed value, bool precision=true);
+
   /**
    * Sets the InfoBox comment to the given Value
    * @param Value New value of the InfoBox comment
@@ -146,6 +151,11 @@ struct InfoBoxData {
    */
   void SetCommentFromSpeed(fixed value, bool precision=true);
 
+  /**
+   * Set the InfoBox comment to the specified task speed.
+   */
+  void SetCommentFromTaskSpeed(fixed value, bool precision=true);
+
   /**
    * Set the InfoBox value to the specified altitude in the alternate
    * altitude unit.
