@@ -3,18 +3,15 @@
  *   British Columbia.
  * Copyright (c) 2001-2003 Michael David Adams.
  * All rights reserved.
-
-   Revision:
-     11/07/2003 15:00 - auxBuffer added for j_image_t : dima <dima@dimin.net>
  */
 
 /* __START_OF_JASPER_LICENSE__
  * 
  * JasPer License Version 2.0
  * 
+ * Copyright (c) 2001-2006 Michael David Adams
  * Copyright (c) 1999-2000 Image Power, Inc.
  * Copyright (c) 1999-2000 The University of British Columbia
- * Copyright (c) 2001-2003 Michael David Adams
  * 
  * All rights reserved.
  * 
@@ -77,7 +74,9 @@
 * Includes.
 \******************************************************************************/
 
+/* The configuration header file should be included first. */
 #include <jasper/jas_config.h>
+
 #include <jasper/jas_stream.h>
 #include <jasper/jas_seq.h>
 #include <jasper/jas_cm.h>
@@ -95,8 +94,12 @@ extern "C" {
  * Miscellaneous constants.
  */
 
+/* Basic units */
+#define JAS_IMAGE_KIBI			(JAS_CAST(size_t, 1024))
+#define JAS_IMAGE_MEBI			(JAS_IMAGE_KIBI * JAS_IMAGE_KIBI)
+
 /* The threshold at which image data is no longer stored in memory. */
-#define JAS_IMAGE_INMEMTHRESH	(16 * 1024 * 1024)
+#define JAS_IMAGE_INMEMTHRESH	(256 * JAS_IMAGE_MEBI)
 
 /*
  * Component types
@@ -122,6 +125,8 @@ extern "C" {
 
 /* Image coordinate. */
 typedef int_fast32_t jas_image_coord_t;
+#define JAS_IMAGE_COORD_MAX INT_FAST32_MAX
+#define JAS_IMAGE_COORD_MIN INT_FAST32_MIN
 
 /* Color space (e.g., RGB, YCbCr). */
 typedef int_fast16_t jas_image_colorspc_t;
@@ -183,15 +188,6 @@ typedef struct {
 
 /* Image class. */
 
-// dima 
-// this field here added for aditional information about the image
-// e.g. GeoTiff information
-typedef struct {
-  int id;    // just some info about the buffer contents
-  long size; // size of the buffer
-  unsigned char *buf; // the buffer itself
-} jas_aux_buffer_t;
-
 typedef struct {
 
 	jas_image_coord_t tlx_;
@@ -222,13 +218,7 @@ typedef struct {
 
 	jas_cmprof_t *cmprof_;
 
-	bool inmem_;
-
-  // dima 
-  // this field here added for aditional information about the image
-  // e.g. GeoTiff information
-  jas_aux_buffer_t aux_buf;
-
+//	bool inmem_;
 
 } jas_image_t;
 
@@ -316,17 +306,17 @@ typedef struct {
 \******************************************************************************/
 
 /* Create an image. */
-jas_image_t *jas_image_create(int numcmpts,
+JAS_DLLEXPORT jas_image_t *jas_image_create(int numcmpts,
   jas_image_cmptparm_t *cmptparms, jas_clrspc_t clrspc);
 
 /* Create an "empty" image. */
-jas_image_t *jas_image_create0(void);
+JAS_DLLEXPORT jas_image_t *jas_image_create0(void);
 
 /* Clone an image. */
-jas_image_t *jas_image_copy(jas_image_t *image);
+JAS_DLLEXPORT jas_image_t *jas_image_copy(jas_image_t *image);
 
 /* Deallocate any resources associated with an image. */
-void jas_image_destroy(jas_image_t *image);
+JAS_DLLEXPORT void jas_image_destroy(jas_image_t *image);
 
 /* Get the width of the image in units of the image reference grid. */
 #define jas_image_width(image) \
@@ -417,38 +407,41 @@ void jas_image_destroy(jas_image_t *image);
 	((image)->cmpts_[cmptno]->tly_ + (image)->cmpts_[cmptno]->height_ * \
 	  (image)->cmpts_[cmptno]->vstep_)
 
+// Test if all components are specified at the same positions in space. */
+JAS_DLLEXPORT bool jas_image_cmpt_domains_same(jas_image_t *image);
+
 /* Get the raw size of an image (i.e., the nominal size of the image without
   any compression. */
-uint_fast32_t jas_image_rawsize(jas_image_t *image);
+JAS_DLLEXPORT uint_fast32_t jas_image_rawsize(jas_image_t *image);
 
 /* Create an image from a stream in some specified format. */
-jas_image_t *jas_image_decode(jas_stream_t *in, int fmt, const char *optstr);
+JAS_DLLEXPORT jas_image_t *jas_image_decode(jas_stream_t *in, int fmt, const char *optstr);
 
 /* Write an image to a stream in a specified format. */
-int jas_image_encode(jas_image_t *image, jas_stream_t *out, int fmt,
+JAS_DLLEXPORT int jas_image_encode(jas_image_t *image, jas_stream_t *out, int fmt,
   const char *optstr);
 
 /* Read a rectangular region of an image component. */
 /* The position and size of the rectangular region to be read is specified
 relative to the component's coordinate system. */
-int jas_image_readcmpt(jas_image_t *image, int cmptno,
-  jas_image_coord_t x, jas_image_coord_t y, jas_image_coord_t width, jas_image_coord_t height,
+JAS_DLLEXPORT int jas_image_readcmpt(jas_image_t *image, int cmptno, jas_image_coord_t x,
+  jas_image_coord_t y, jas_image_coord_t width, jas_image_coord_t height,
   jas_matrix_t *data);
 
 /* Write a rectangular region of an image component. */
-int jas_image_writecmpt(jas_image_t *image, int cmptno,
-  jas_image_coord_t x, jas_image_coord_t y, jas_image_coord_t width, jas_image_coord_t height,
+JAS_DLLEXPORT int jas_image_writecmpt(jas_image_t *image, int cmptno, jas_image_coord_t x,
+  jas_image_coord_t y, jas_image_coord_t width, jas_image_coord_t height,
   jas_matrix_t *data);
 
 /* Delete a component from an image. */
-void jas_image_delcmpt(jas_image_t *image, int cmptno);
+JAS_DLLEXPORT void jas_image_delcmpt(jas_image_t *image, int cmptno);
 
 /* Add a component to an image. */
-int jas_image_addcmpt(jas_image_t *image, int cmptno,
+JAS_DLLEXPORT int jas_image_addcmpt(jas_image_t *image, int cmptno,
   jas_image_cmptparm_t *cmptparm);
 
 /* Copy a component from one image to another. */
-int jas_image_copycmpt(jas_image_t *dstimage, int dstcmptno,
+JAS_DLLEXPORT int jas_image_copycmpt(jas_image_t *dstimage, int dstcmptno,
   jas_image_t *srcimage, int srccmptno);
 
 #define	JAS_IMAGE_CDT_GETSGND(dtype) (((dtype) >> 7) & 1)
@@ -459,43 +452,43 @@ int jas_image_copycmpt(jas_image_t *dstimage, int dstcmptno,
 #define	jas_image_cmptdtype(image, cmptno) \
 	(JAS_IMAGE_CDT_SETSGND((image)->cmpts_[cmptno]->sgnd_) | JAS_IMAGE_CDT_SETPREC((image)->cmpts_[cmptno]->prec_))
 
-int jas_image_depalettize(jas_image_t *image, int cmptno, int numlutents,
+JAS_DLLEXPORT int jas_image_depalettize(jas_image_t *image, int cmptno, int numlutents,
   int_fast32_t *lutents, int dtype, int newcmptno);
 
-int jas_image_readcmptsample(jas_image_t *image, int cmptno, int x, int y);
-void jas_image_writecmptsample(jas_image_t *image, int cmptno, int x, int y,
+JAS_DLLEXPORT int jas_image_readcmptsample(jas_image_t *image, int cmptno, int x, int y);
+JAS_DLLEXPORT void jas_image_writecmptsample(jas_image_t *image, int cmptno, int x, int y,
   int_fast32_t v);
 
-int jas_image_getcmptbytype(jas_image_t *image, int ctype);
+JAS_DLLEXPORT int jas_image_getcmptbytype(jas_image_t *image, int ctype);
 
 /******************************************************************************\
 * Image format-related operations.
 \******************************************************************************/
 
 /* Clear the table of image formats. */
-void jas_image_clearfmts(void);
+JAS_DLLEXPORT void jas_image_clearfmts(void);
 
 /* Add entry to table of image formats. */
-int jas_image_addfmt(int id, const char *name, const char *ext, const char *desc,
+JAS_DLLEXPORT int jas_image_addfmt(int id, const char *name, const char *ext, const char *desc,
   jas_image_fmtops_t *ops);
 
 /* Get the ID for the image format with the specified name. */
-int jas_image_strtofmt(char *s);
+JAS_DLLEXPORT int jas_image_strtofmt(char *s);
 
 /* Get the name of the image format with the specified ID. */
-char *jas_image_fmttostr(int fmt);
+JAS_DLLEXPORT char *jas_image_fmttostr(int fmt);
 
 /* Lookup image format information by the format ID. */
-jas_image_fmtinfo_t *jas_image_lookupfmtbyid(int id);
+JAS_DLLEXPORT jas_image_fmtinfo_t *jas_image_lookupfmtbyid(int id);
 
 /* Lookup image format information by the format name. */
-jas_image_fmtinfo_t *jas_image_lookupfmtbyname(const char *name);
+JAS_DLLEXPORT jas_image_fmtinfo_t *jas_image_lookupfmtbyname(const char *name);
 
 /* Guess the format of an image file based on its name. */
-int jas_image_fmtfromname(char *filename);
+JAS_DLLEXPORT int jas_image_fmtfromname(char *filename);
 
 /* Get the format of image data in a stream. */
-int jas_image_getfmt(jas_stream_t *in);
+JAS_DLLEXPORT int jas_image_getfmt(jas_stream_t *in);
 
 
 #define	jas_image_cmprof(image)	((image)->cmprof_)
@@ -511,7 +504,7 @@ int jas_image_readcmpt2(jas_image_t *image, int cmptno, jas_image_coord_t x,
   long *buf);
 
 #define	jas_image_setcmprof(image, cmprof) ((image)->cmprof_ = cmprof)
-jas_image_t *jas_image_chclrspc(jas_image_t *image, jas_cmprof_t *outprof,
+JAS_DLLEXPORT jas_image_t *jas_image_chclrspc(jas_image_t *image, jas_cmprof_t *outprof,
   int intent);
 void jas_image_dump(jas_image_t *image, FILE *out);
 
@@ -575,14 +568,6 @@ int pgx_encode(jas_image_t *image, jas_stream_t *out, const char *optstr);
 int pgx_validate(jas_stream_t *in);
 #endif
 
-#if !defined(EXCLUDE_TIFF_SUPPORT)
-/* Format-dependent operations for TIFF support. */
-jas_image_t *tiff_decode(jas_stream_t *in, char *optstr);
-int tiff_encode(jas_image_t *image, jas_stream_t *out, char *optstr);
-int tiff_validate(jas_stream_t *in);
-#endif
-
-
 #ifdef __cplusplus
 }
 #endif
