@@ -123,6 +123,8 @@ private:
   virtual void OnTraffic(uint32_t pilot_id, unsigned time_of_day_ms,
                          const GeoPoint &location, int altitude) override;
     virtual void OnUserName(uint32_t user_id, const TCHAR *name) override;
+  void OnWave(unsigned time_of_day_ms,
+              const GeoPoint &a, const GeoPoint &b) override;
 
 public:
   const SkyLinesTracking::Data &GetSkyLinesData() const {
